@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2015-2016 Luca Falavigna
+# Copyright (C) 2015-2018 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -28,22 +28,24 @@ from .exceptions import DebomaticConffileError
 
 core = {'debomatic':
         {'debootstrap': str, 'incoming': str, 'architecture': str,
-         'threads': int, 'inotify': bool, 'sleep': int,
+         'threads': int, 'inotify': bool, 'sleep': int, 'interval': int,
          'logfile': str, 'loglevel': str},
         'distributions': {'list': str, 'blacklist': str, 'mapper': dict},
         'chroots': {'profile': str, 'commands': str},
         'gpg': {'gpg': bool, 'keyring': str},
         'modules': {'modules': bool, 'path': str,
                     'threads': int, 'blacklist': str}}
-optional = {'crossbuild': {'crossbuild': bool, 'hostarchitecture': str}}
+optional = {'crossbuild': {'crossbuild': bool, 'hostarchitecture': str},
+            'dpr': {'dpr': bool, 'prefix': str, 'repository': str}}
 modules = {'autopkgtest': {'options': str},
            'blhc': {'options': str},
+           'buildcleaner': {'testbuild': bool},
            'lintian': {'options': str},
            'mailer': {'sender': str, 'server': str, 'port': int, 'tls': bool,
                       'authrequired': bool, 'user': str, 'passwd': str,
                       'success': str, 'failure': str, 'lintian': bool},
            'piuparts': {'options': str},
-           'repository': {'gpgkey': str, 'pubring': str, 'secring': str}}
+           'repository': {'gpgkey': str, 'pubring': str}}
 dists = {'suite': str, 'mirror': str, 'components': str,
          '_extramirrors': str, '_extrapackages': str}
 
