@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2016 Luca Falavigna
+# Copyright (C) 2007-2018 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -31,7 +31,7 @@ from .commands import Command
 from .configuration import Parser
 from .exceptions import DebomaticConffileError, DebomaticError
 from .modules import Module
-from .process import Process, ThreadPool
+from .process import Process, ThreadPool, Timer
 
 
 class Debomatic(Parser, Process):
@@ -71,6 +71,8 @@ class Debomatic(Parser, Process):
             error(_('Unable to access %s directory') % self.incoming)
             exit(1)
         dom.pool = ThreadPool(dom.opts.getint('debomatic', 'threads'))
+        dom.periodic_event = Timer(dom.opts.getint('debomatic', 'interval'),
+                                   self.periodic_event)
         dom.buildqueue = []
         dom.chroots = {}
         self.logfile = dom.opts.get('debomatic', 'logfile')
@@ -170,3 +172,8 @@ class Debomatic(Parser, Process):
             for handler in old_log.handlers:
                 old_log.removeHandler(handler)
         log(level=self.loglevel, format=fmt)
+
+    def periodic_event(self):
+        self.mod_sys.args.opts = dom.opts
+        self.mod_sys.args.directory = self.incoming
+        self.mod_sys.execute_hook('periodic')
