@@ -1,7 +1,7 @@
 # Deb-o-Matic
 #
 # Copyright (C) 2008-2009 David Futcher
-# Copyright (C) 2012-2016 Luca Falavigna
+# Copyright (C) 2012-2018 Luca Falavigna
 #
 # Author: David Futcher <bobbo@ubuntu.com>
 #
@@ -56,12 +56,15 @@ class Module():
                 self._use_modules = True
         if dom.opts.has_option('modules', 'path'):
             mod_path = dom.opts.get('modules', 'path')
-            path.append(mod_path)
+            for p in mod_path.split(':'):
+                path.append(p)
         else:
             self._use_modules = False
+        modules = set()
         try:
-            modules = set([os.path.splitext(os.path.basename(m))[0] for m in
-                           glob(os.path.join(mod_path, '*.py'))])
+            for p in mod_path.split(':'):
+                modules |= set([os.path.splitext(os.path.basename(m))[0] for m in
+                               glob(os.path.join(p, '*.py'))])
         except OSError:
             self._use_modules = False
         if not modules:
