@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2012-2016 Luca Falavigna
+# Copyright (C) 2012-2018 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -25,9 +25,9 @@ templates_path = ['_templates']
 source_suffix = '.rst'
 master_doc = 'index'
 project = 'Deb-o-Matic'
-copyright = '2007-2016, Luca Falavigna'
-version = '0.22'
-release = '0.22'
+copyright = '2007-2018, Luca Falavigna'
+version = '0.24'
+release = '0.24'
 exclude_patterns = ['_build']
 pygments_style = 'sphinx'
 html_theme = 'default'
@@ -36,7 +36,7 @@ html_use_index = True
 htmlhelp_basename = 'Deb-o-Maticdoc'
 latex_documents = [
     ('index', 'Deb-o-Matic.tex', 'Deb-o-Matic Documentation',
-     'Luca Falavigna', 'manual')]
+     'Luca Falavigna', 'manual', 'True')]
 latex_elements = {
     'classoptions': ',oneside',
     'babel': '\\usepackage[english]{babel}'}
