@@ -1,7 +1,7 @@
 # Deb-o-Matic - AutoPkgTest module
 #
 # Copyright (C) 2014 Leo Iannacone
-# Copyright (C) 2015-2016 Luca Falavigna
+# Copyright (C) 2015-2018 Luca Falavigna
 #
 # Authors: Leo Iannacone <l3on@ubuntu.com>
 #
@@ -29,7 +29,7 @@
 
 import os
 from subprocess import call
-from shutil import rmtree
+from shutil import copyfile, rmtree
 
 
 class DebomaticModule_AutoPkgTest:
@@ -38,6 +38,7 @@ class DebomaticModule_AutoPkgTest:
         self.adt = '/usr/bin/autopkgtest'
         self.options = []
         self.changesfile = None
+        self.after = ['Lintian']
 
     def _set_up_testbed(self, args):
         """Performs:
@@ -86,6 +87,16 @@ class DebomaticModule_AutoPkgTest:
         if not self._set_up_testbed(args):
             return
 
+        tempfiles = set()
+        for pkgfile in args.files:
+            target = os.path.join(self.resultdir, os.path.basename(pkgfile))
+            if not os.path.exists(target):
+                try:
+                    copyfile(pkgfile, target)
+                    tempfiles.add(target)
+                except (IOError, OSError):
+                    pass
+
         output = open(self.output, 'w')
 
         def write_header(header):
@@ -143,3 +154,5 @@ class DebomaticModule_AutoPkgTest:
         # clean up the system
         if (os.path.isdir(self.resultdir_adt)):
             rmtree(self.resultdir_adt)
+        for pkgfile in tempfiles:
+            os.remove(pkgfile)
