@@ -1,6 +1,6 @@
-# Deb-o-Matic - Contents module
+# Deb-o-Matic - Repository module
 #
-# Copyright (C) 2011-2016 Luca Falavigna
+# Copyright (C) 2011-2018 Luca Falavigna
 #
 # Authors: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -20,7 +20,6 @@
 # Generate local repository of built packages
 
 import os
-from datetime import datetime
 from fcntl import flock, LOCK_EX, LOCK_NB, LOCK_SH, LOCK_UN
 from shutil import rmtree
 from stat import S_IRWXU, S_IRGRP, S_IXGRP, S_IROTH, S_IXOTH
@@ -71,18 +70,13 @@ class DebomaticModule_Repository:
         if args.opts.has_section('repository'):
             gpgkey = args.opts.get('repository', 'gpgkey')
             pubring = args.opts.get('repository', 'pubring')
-            secring = args.opts.get('repository', 'secring')
         else:
             return
         if not os.access(self.af, os.X_OK):
             return
         if not os.access(self.gpg, os.X_OK):
             return
-        distribution = args.distribution
-        if args.hostarchitecture:
-            arch = args.hostarchitecture
-        else:
-            arch = args.architecture
+        distribution = os.path.basename(args.directory)
         archive = args.directory
         pool = os.path.join(archive, 'pool')
         distslink = os.path.join(archive, 'dists', distribution)
@@ -92,62 +86,62 @@ class DebomaticModule_Repository:
             tmpdir = mkdtemp(prefix='.', dir=os.path.join(archive, 'dists'))
             os.symlink(tmpdir, distslink)
         dists = mkdtemp(prefix='.', dir=os.path.join(archive, 'dists'))
-        packages = os.path.join(dists, 'main', 'binary-%s' % arch)
-        packages_file = os.path.join(packages, 'Packages')
-        arch_release_file = os.path.join(packages, 'Release')
-        release_file = os.path.join(dists, 'Release')
-        release_gpg = os.path.join(dists, 'Release.gpg')
-        inrelease_gpg = os.path.join(dists, 'InRelease')
-        for dir in (pool, packages):
-            if not os.path.isdir(dir):
-                os.makedirs(dir)
-        with self.Lock(distribution, arch) as lock:
-            if lock.skip():
-                rmtree(dists)
-            else:
-                with open(packages_file, 'w') as fd:
-                    Popen([self.af, 'packages', 'pool'],
-                          stdout=fd, stderr=PIPE, cwd=archive).wait()
-                with open(arch_release_file, 'w') as fd:
-                    fd.write('Origin: Deb-O-Matic\n')
-                    fd.write('Label: Deb-O-Matic\n')
-                    fd.write('Archive: %s\n' % distribution)
-                    fd.write('Component: main\n')
-                    fd.write('Architecture: %s\n' % arch)
-                with open(release_file, 'w') as fd:
-                    date = datetime.now().strftime('%A, %d %B %Y %H:%M:%S')
-                    afstring = 'APT::FTPArchive::Release::'
-                    Popen([self.af, '-qq',
-                           '-o', '%sOrigin=Deb-o-Matic' % afstring,
-                           '-o', '%sLabel=Deb-o-Matic' % afstring,
-                           '-o', '%sSuite=%s' % (afstring, distribution),
-                           '-o', '%sDate=%s' % (afstring, date),
-                           '-o', '%sArchitectures=%s' % (afstring, arch),
-                           '-o', '%sComponents=main' % afstring,
-                           'release', 'dists/%s' % os.path.basename(dists)],
-                          stdout=fd, stderr=PIPE, cwd=archive).wait()
-                with open(release_file, 'r+') as fd:
-                    data = fd.read()
-                    fd.seek(0)
-                    fd.write(data.replace('MD5Sum',
-                             'NotAutomatic: yes\nMD5Sum'))
+        for arch in [a for a in (args.architecture,
+                                 args.hostarchitecture) if a is not None]:
+            packages = os.path.join(dists, 'main', 'binary-%s' % arch)
+            packages_file = os.path.join(packages, 'Packages')
+            arch_release_file = os.path.join(packages, 'Release')
+            release_file = os.path.join(dists, 'Release')
+            release_gpg = os.path.join(dists, 'Release.gpg')
+            inrelease_gpg = os.path.join(dists, 'InRelease')
+            for dir in (pool, packages):
+                if not os.path.isdir(dir):
+                    os.makedirs(dir)
+            with self.Lock(distribution, arch) as lock:
+                if not lock.skip():
+                    with open(packages_file, 'w') as fd:
+                        Popen([self.af, '-a', arch, 'packages', 'pool'],
+                              stdout=fd, stderr=PIPE, cwd=archive).wait()
+                    with open(arch_release_file, 'w') as fd:
+                        fd.write('Origin: Deb-O-Matic\n')
+                        fd.write('Label: Deb-O-Matic\n')
+                        fd.write('Archive: %s\n' % distribution)
+                        fd.write('Component: main\n')
+                        fd.write('Architecture: %s\n' % arch)
+                    with open(release_file, 'w') as fd:
+                        afstring = 'APT::FTPArchive::Release::'
+                        Popen([self.af, '-qq',
+                               '-o', '%sOrigin=Deb-o-Matic' % afstring,
+                               '-o', '%sLabel=Deb-o-Matic' % afstring,
+                               '-o', '%sSuite=%s' % (afstring, distribution),
+                               '-o', '%sArchitectures=%s' % (afstring, arch),
+                               '-o', '%sComponents=main' % afstring,
+                               'release',
+                               'dists/%s' % os.path.basename(dists)],
+                              stdout=fd, stderr=PIPE, cwd=archive).wait()
+                    with open(release_file, 'r+') as fd:
+                        data = fd.read()
+                        fd.seek(0)
+                        fd.write(data.replace('MD5Sum',
+                                 'NotAutomatic: yes\nMD5Sum'))
                 with open(release_gpg, 'w') as fd:
                     Popen([self.gpg, '--no-default-keyring', '--keyring',
-                           pubring, '--secret-keyring', secring,
-                           '-u', gpgkey, '--yes', '-a', '-o', fd.name,
+                           pubring, '-u', gpgkey, '--yes', '-a', '-o', fd.name,
                            '-b', release_file], cwd=archive).wait()
                 with open(inrelease_gpg, 'w') as fd:
                     Popen([self.gpg, '--no-default-keyring', '--keyring',
-                           pubring, '--secret-keyring', secring,
-                           '-u', gpgkey, '--yes', '-a', '-o', fd.name,
+                           pubring, '-u', gpgkey, '--yes', '-a', '-o', fd.name,
                            '--clearsign', release_file], cwd=archive).wait()
-                olddists = os.readlink(distslink)
-                (tmp, tmplink) = mkstemp(prefix='.',
-                                         dir=os.path.dirname(olddists))
-                os.close(tmp)
-                os.unlink(tmplink)
-                os.symlink(dists, tmplink)
-                os.chmod(dists, S_IRWXU | S_IRGRP | S_IXGRP |
-                         S_IROTH | S_IXOTH)
-                os.rename(tmplink, distslink)
-                rmtree(olddists)
+        olddists = os.readlink(distslink)
+        (tmp, tmplink) = mkstemp(prefix='.',
+                                 dir=os.path.dirname(olddists))
+        os.close(tmp)
+        os.unlink(tmplink)
+        os.symlink(dists, tmplink)
+        os.chmod(dists, S_IRWXU | S_IRGRP | S_IXGRP |
+                 S_IROTH | S_IXOTH)
+        os.rename(tmplink, distslink)
+        try:
+            rmtree(olddists)
+        except FileNotFoundError:
+            pass
